==> spread-5.3.0.5-py3-none-any.whl: spread_mercury/errors.py <==
class MError(BaseException):
    def __init__(self, message, **params):
        super().__init__()
        self.message = message
        self.params = params

    def __str__(self):
        res = '[{}]: {}'.format(self.__class__.__name__, self.message)
        if len(self.params) > 0:
            for param in self.params:
                res += '\n      {}: {}'.format(param, self.params[param])
        return res


class WrongCRC16(MError):
    def __init__(self):
        super().__init__('Неверная контрольная сумма ответа!')


class WriteError(MError):
    def __init__(self, cmd, byte_code, text):
        super().__init__(f'({byte_code}) {text} для {cmd}')


class BadConnectResponse(MError):
    def __init__(self):
        super().__init__('Ошибка теста канала связи')


class AccessError(MError):
    def __init__(self, address, level):
        super(AccessError, self).__init__('Ошибка доступа r адресу {} с уровнем доступа {}'.format(address, level))


class TimeOutError(MError):
    """
    Возможные причины:
     − не совпал адрес в последовательности запроса с сетевым адресом счётчика;
     - не совпала контрольная сумма запроса,переданного в канал связи
        с посчитанной контрольной суммой запроса после принятия его счётчиком;
     − обращение на запись по адресу 0;
     - неверное число байт запроса.
    """
    def __init__(self, cmd):
        super().__init__('  X: {} {}'.format(self.__class__.__name__, cmd))

    def __str__(self): return self.message


class PackageError(MError):
    def __init__(self, message, **params):
        super(PackageError, self).__init__(message, **params)

==> spread-5.8.1.80-py3-none-any.whl: spread_mercury/errors.py <==
class MError(BaseException):
    def __init__(self, message, **params):
        super().__init__()
        self.message = message
        self.params = params

    def __str__(self):
        res = '[{}]: {}'.format(self.__class__.__name__, self.message)
        if len(self.params) > 0:
            for param in self.params:
                res += '\n      {}: {}'.format(param, self.params[param])
        return res


class WrongCRC16(MError):
    def __init__(self):
        super().__init__('Неверная контрольная сумма ответа!')


class WriteError(MError):
    def __init__(self, cmd, byte_code, text):
        super().__init__(f'({byte_code}) {text} для {cmd}')


class BadConnectResponse(MError):
    def __init__(self):
        super().__init__('Ошибка теста канала связи')


class AccessError(MError):
    def __init__(self, address, level):
        super(AccessError, self).__init__('Ошибка доступа к адресу {} с уровнем доступа {}'.format(address, level))


class TimeOutError(MError):
    """
    Возможные причины:
     − не совпал адрес в последовательности запроса с сетевым адресом счётчика;
     - не совпала контрольная сумма запроса, переданного в канал связи
        с посчитанной контрольной суммой запроса после принятия его счётчиком;
     − обращение на запись по адресу 0;
     - неверное число байт запроса.
    """
    def __init__(self, cmd):
        super().__init__('  X: {} {}'.format(self.__class__.__name__, cmd))

    def __str__(self): return self.message


class PackageError(MError):
    def __init__(self, message, **params):
        super(PackageError, self).__init__(message, **params)
